@@ -9,15 +9,20 @@ import (
 	"runtime"
 	godebug "runtime/debug"
 
+	"github.com/spf13/cobra"
+	"go.uber.org/automaxprocs/maxprocs"
+
 	"github.com/restic/restic/internal/debug"
+	"github.com/restic/restic/internal/errors"
 	"github.com/restic/restic/internal/options"
 	"github.com/restic/restic/internal/restic"
-
-	"github.com/spf13/cobra"
-
-	"github.com/restic/restic/internal/errors"
 )
 
+func init() {
+	// don't import `go.uber.org/automaxprocs` to disable the log output
+	_, _ = maxprocs.Set()
+}
+
 // cmdRoot is the base command when no other command has been specified.
 var cmdRoot = &cobra.Command{
 	Use:   "restic",
@@ -75,7 +80,7 @@ The full documentation can be found at https://restic.readthedocs.io/ .
 // user for authentication).
 func needsPassword(cmd string) bool {
 	switch cmd {
-	case "cache", "generate", "help", "options", "self-update", "version":
+	case "cache", "generate", "help", "options", "self-update", "version", "__complete":
 		return false
 	default:
 		return true
