@@ -8,8 +8,8 @@ import (
 
 // Migration implements a data migration.
 type Migration interface {
-	// Check returns true if the migration can be applied to a repo.
-	Check(context.Context, restic.Repository) (bool, error)
+	// Check returns true if the migration can be applied to a repo. If the option is not applicable it can return a specific reason.
+	Check(context.Context, restic.Repository) (bool, string, error)
 
 	RepoCheck() bool
 
