@@ -29,7 +29,7 @@ func Repack(ctx context.Context, repo restic.Repository, dstRepo restic.Reposito
 	debug.Log("repacking %d packs while keeping %d blobs", len(packs), keepBlobs.Len())
 
 	if repo == dstRepo && dstRepo.Connections() < 2 {
-		return nil, errors.Fatal("repack step requires a backend connection limit of at least two")
+		return nil, errors.New("repack step requires a backend connection limit of at least two")
 	}
 
 	wg, wgCtx := errgroup.WithContext(ctx)
