@@ -6,13 +6,9 @@ func (node Node) restoreSymlinkTimestamps(path string, utimes [2]syscall.Timespe
 	return nil
 }
 
-func (node Node) device() int {
-	return int(node.Device)
-}
-
-func (s statUnix) atim() syscall.Timespec { return s.Atimespec }
-func (s statUnix) mtim() syscall.Timespec { return s.Mtimespec }
-func (s statUnix) ctim() syscall.Timespec { return s.Ctimespec }
+func (s statT) atim() syscall.Timespec { return s.Atimespec }
+func (s statT) mtim() syscall.Timespec { return s.Mtimespec }
+func (s statT) ctim() syscall.Timespec { return s.Ctimespec }
 
 // Getxattr retrieves extended attribute data associated with path.
 func Getxattr(path, name string) ([]byte, error) {
