@@ -15,8 +15,8 @@ type ProgressPrinter interface {
 	Update(total, processed Counter, errors uint, currentFiles map[string]struct{}, start time.Time, secs uint64)
 	Error(item string, err error) error
 	ScannerError(item string, err error) error
-	CompleteItem(messageType string, item string, previous, current *restic.Node, s archiver.ItemStats, d time.Duration)
-	ReportTotal(item string, start time.Time, s archiver.ScanStats)
+	CompleteItem(messageType string, item string, s archiver.ItemStats, d time.Duration)
+	ReportTotal(start time.Time, s archiver.ScanStats)
 	Finish(snapshotID restic.ID, start time.Time, summary *Summary, dryRun bool)
 	Reset()
 
@@ -43,7 +43,8 @@ type Progress struct {
 	progress.Updater
 	mu sync.Mutex
 
-	start time.Time
+	start     time.Time
+	estimator rateEstimator
 
 	scanStarted, scanFinished bool
 
@@ -60,6 +61,7 @@ func NewProgress(printer ProgressPrinter, interval time.Duration) *Progress {
 		start:        time.Now(),
 		currentFiles: make(map[string]struct{}),
 		printer:      printer,
+		estimator:    *newRateEstimator(time.Now()),
 	}
 	p.Updater = *progress.NewUpdater(interval, func(runtime time.Duration, final bool) {
 		if final {
@@ -73,9 +75,14 @@ func NewProgress(printer ProgressPrinter, interval time.Duration) *Progress {
 
 			var secondsRemaining uint64
 			if p.scanFinished {
-				secs := float64(runtime / time.Second)
-				todo := float64(p.total.Bytes - p.processed.Bytes)
-				secondsRemaining = uint64(secs / float64(p.processed.Bytes) * todo)
+				rate := p.estimator.rate(time.Now())
+				tooSlowCutoff := 1024.
+				if rate <= tooSlowCutoff {
+					secondsRemaining = 0
+				} else {
+					todo := float64(p.total.Bytes - p.processed.Bytes)
+					secondsRemaining = uint64(todo / rate)
+				}
 			}
 
 			p.printer.Update(p.total, p.processed, p.errors, p.currentFiles, p.start, secondsRemaining)
@@ -105,6 +112,7 @@ func (p *Progress) addProcessed(c Counter) {
 	p.processed.Files += c.Files
 	p.processed.Dirs += c.Dirs
 	p.processed.Bytes += c.Bytes
+	p.estimator.recordBytes(time.Now(), c.Bytes)
 	p.scanStarted = true
 }
 
@@ -144,19 +152,19 @@ func (p *Progress) CompleteItem(item string, previous, current *restic.Node, s a
 
 		switch {
 		case previous == nil:
-			p.printer.CompleteItem("dir new", item, previous, current, s, d)
+			p.printer.CompleteItem("dir new", item, s, d)
 			p.mu.Lock()
 			p.summary.Dirs.New++
 			p.mu.Unlock()
 
 		case previous.Equals(*current):
-			p.printer.CompleteItem("dir unchanged", item, previous, current, s, d)
+			p.printer.CompleteItem("dir unchanged", item, s, d)
 			p.mu.Lock()
 			p.summary.Dirs.Unchanged++
 			p.mu.Unlock()
 
 		default:
-			p.printer.CompleteItem("dir modified", item, previous, current, s, d)
+			p.printer.CompleteItem("dir modified", item, s, d)
 			p.mu.Lock()
 			p.summary.Dirs.Changed++
 			p.mu.Unlock()
@@ -170,19 +178,19 @@ func (p *Progress) CompleteItem(item string, previous, current *restic.Node, s a
 
 		switch {
 		case previous == nil:
-			p.printer.CompleteItem("file new", item, previous, current, s, d)
+			p.printer.CompleteItem("file new", item, s, d)
 			p.mu.Lock()
 			p.summary.Files.New++
 			p.mu.Unlock()
 
 		case previous.Equals(*current):
-			p.printer.CompleteItem("file unchanged", item, previous, current, s, d)
+			p.printer.CompleteItem("file unchanged", item, s, d)
 			p.mu.Lock()
 			p.summary.Files.Unchanged++
 			p.mu.Unlock()
 
 		default:
-			p.printer.CompleteItem("file modified", item, previous, current, s, d)
+			p.printer.CompleteItem("file modified", item, s, d)
 			p.mu.Lock()
 			p.summary.Files.Changed++
 			p.mu.Unlock()
@@ -200,7 +208,7 @@ func (p *Progress) ReportTotal(item string, s archiver.ScanStats) {
 
 	if item == "" {
 		p.scanFinished = true
-		p.printer.ReportTotal(item, p.start, s)
+		p.printer.ReportTotal(p.start, s)
 	}
 }
 
